==> apache-nuttx-10.2.0-incubating.tar.gz: nuttx/arch/xtensa/src/esp32/esp32_pminitialize.c <==
/****************************************************************************
 * arch/xtensa/src/esp32/esp32_pminitialize.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <nuttx/power/pm.h>

#include "esp32_pm.h"

#ifdef CONFIG_PM

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: xtensa_pminitialize
 *
 * Description:
 *   Initialize the power management subsystem.
 *
 ****************************************************************************/

void xtensa_pminitialize(void)
{
  /* Initialize RTC parameters */

  esp32_pminit();

  /* Then initialize the NuttX power management subsystem proper */

  pm_initialize();
}

#endif /* CONFIG_PM */

==> apache-nuttx-10.3.0-incubating.tar.gz: nuttx/arch/xtensa/src/esp32/esp32_pminitialize.c <==
/****************************************************************************
 * arch/xtensa/src/esp32/esp32_pminitialize.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>

#include "xtensa.h"
#include "esp32_pm.h"

#ifdef CONFIG_PM

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: xtensa_pminitialize
 *
 * Description:
 *   Initialize the power management subsystem.
 *
 ****************************************************************************/

void xtensa_pminitialize(void)
{
  /* Initialize RTC parameters */

  esp32_pminit();
}

#endif /* CONFIG_PM */
